==> developer-center-api-1.6.5-20170117.115243-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/CreditsFloorCodeDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;


import java.io.Serializable;
import java.util.Date;

import javax.validation.constraints.NotNull;

/**
 * Created by suyuanlong on 16/8/10.
 */
public class CreditsFloorCodeDto implements Serializable {
    private static final long serialVersionUID = 8765366004025671569L;

    public static final String GET_CACHE_KEY="MAX_CREDITS_FLOOR_CODE_";

    private Long id;
    @NotNull
    private String floorName;
    @NotNull
    private String md5;
    @NotNull
    private String sourceUrl;
    @NotNull
    private Short floorType;
    @NotNull
    private String image;
    @NotNull
    private Long adminId;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public String getFloorName() {
        return floorName;
    }

    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public Short getFloorType() {
        return floorType;
    }

    public void setFloorType(Short floorType) {
        this.floorType = floorType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public String getSourceUrl() {
        return sourceUrl;
    }

    public void setSourceUrl(String sourceUrl) {
        this.sourceUrl = sourceUrl;
    }
}

==> developer-center-api-2.1.3-20170517.075557-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/CreditsFloorCodeDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;


import java.io.Serializable;
import java.util.Date;

import javax.validation.constraints.NotNull;

/**
 * Created by suyuanlong on 16/8/10.
 */
public class CreditsFloorCodeDto implements CodeDto {
    private static final long serialVersionUID = 8765366004025671569L;

    public static final String GET_CACHE_KEY="MAX_CREDITS_FLOOR_CODE_";

    private Long id;
    @NotNull
    private String floorName;
    @NotNull
    private String md5;
    @NotNull
    private String sourceUrl;
    @NotNull
    private Short floorType;
    @NotNull
    private Integer dataType;
    @NotNull
    private Long adminId;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public String getFloorName() {
        return floorName;
    }

    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public Short getFloorType() {
        return floorType;
    }

    public void setFloorType(Short floorType) {
        this.floorType = floorType;
    }

    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    @Override
    public String getConfigUrl() {
        return sourceUrl;
    }

    public String getSourceUrl() {
        return sourceUrl;
    }

    public void setSourceUrl(String sourceUrl) {
        this.sourceUrl = sourceUrl;
    }
}
